@@ -126,6 +126,14 @@ var csvScenarios = []formatScenario{
 		expected:       expectedYamlFromCSV,
 		scenarioType:   "decode-csv-object",
 	},
+	{
+		description:  "Scalar roundtrip",
+		skipDoc:      true,
+		input:        "mike\ncat",
+		expression:   ".[0].mike",
+		expected:     "cat\n",
+		scenarioType: "roundtrip-csv",
+	},
 	{
 		description:    "Parse TSV into an array of objects",
 		subdescription: "First row is assumed to be the header row.",
