@@ -14,6 +14,13 @@ var collectObjectOperatorScenarios = []expressionScenario{
 			"D0, P[], (!!map)::dog: great\n",
 		},
 	},
+	{
+		skipDoc:    true,
+		expression: `({} + {}) | (.b = 3)`,
+		expected: []string{
+			"D0, P[], (!!map)::b: 3\n",
+		},
+	},
 	{
 		skipDoc:    true,
 		document:   "a: []",
