@@ -21,11 +21,19 @@ var pipeOperatorScenarios = []expressionScenario{
 			"D0, P[], (doc)::{a: cat, b: dog, c: same}\n",
 		},
 	},
+	{
+		skipDoc:     true,
+		description: "Don't pass readonly context",
+		expression:  `(3 + 4) | ({} | .b = "dog")`,
+		expected: []string{
+			"D0, P[], (!!map)::b: dog\n",
+		},
+	},
 }
 
 func TestPipeOperatorScenarios(t *testing.T) {
 	for _, tt := range pipeOperatorScenarios {
 		testScenario(t, &tt)
 	}
-	documentScenarios(t, "pipe", pipeOperatorScenarios)
+	documentOperatorScenarios(t, "pipe", pipeOperatorScenarios)
 }
